<?php
namespace Pinecast\Admin;

use function Pinecast\get_podcasts;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


/**
 * Current admin screen Pinecast?
 *
 * @return bool True when the current screen is related to Pinecast.
 */
function is_pinecast_admin() {
	$pinecast_screen = false;
	$screen = get_current_screen();

	if ( $screen->id === 'settings_page_pinecast' ) {
		$pinecast_screen = true;
	}

	return apply_filters( 'Pinecast/is_pinecast_admin', $pinecast_screen );
}


/**
 * Enqueue scripts.
 *
 * Enqueue script as javascript and stylesheets.
 */
function admin_enqueue_scripts() {
	wp_register_script( 'jquery-repeater', plugins_url( 'dist/admin/js/jquery.repeater.min.js', Pinecast()->file ), array( 'jquery' ), '1.0.0', true );
	wp_register_script( 'pinecast', plugins_url( 'dist/admin/js/pinecast.min.js', Pinecast()->file ), array( 'jquery-repeater' ), Pinecast()->version, true );
	wp_register_style( 'pinecast', plugins_url( 'dist/admin/css/pinecast.min.css', Pinecast()->file ), array(), Pinecast()->version );

	wp_localize_script( 'pinecast', 'pinecast', array(
		'nonce' => wp_create_nonce( 'pinecast-security' )
	) );

	if ( is_pinecast_admin() ) {
		wp_enqueue_script( 'pinecast' );
		wp_enqueue_style( 'pinecast' );
	}
}
add_action( 'admin_enqueue_scripts', 'Pinecast\Admin\admin_enqueue_scripts' );


/**
 * Show admin notices.
 */
function admin_notices() {
	$podcasts = get_option( 'pinecast_feeds', array() );
	if ( empty( $podcasts ) && ! is_pinecast_admin() ) {
		?><div class="notice notice-success">
			<p>
                <strong><?php _e( 'Set up podcasts', 'pinecast' ); ?></strong><br>
			<?php echo sprintf( __( '%sAdd your Pinecast podcast feeds%s to begin syncing your podcast with WordPress.', 'pinecast' ), '<a href="' . admin_url( 'options-general.php?page=pinecast' ) . '">', '</a>' ); ?></p>
		</div><?php
	}
}
add_action( 'admin_notices', 'Pinecast\Admin\admin_notices' );
