<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @var \Pinecast\Podcast[] $podcasts All podcasts
 * @var \Pinecast\Podcast $podcast Current listed podcast
 */

?><div class="pinecast-feed open" data-podcast-id="<?php echo absint( $podcast->get_id() ); ?>">
	<div class="pinecast-feed-header">
		<h2 class="title"><?php
			if ( ! empty( $podcast->get_name() ) ) :
				echo esc_html( $podcast->get_name() );
			else :
				?><span class="placeholder"><?php _e( 'Add a new podcast', 'pinecast' ); ?></span><?php
			endif;
		?></h2>
		<button type="button" class="delete"><?php _e( 'Delete', 'pinecast' ); ?></button>
		<div class="handlediv toggle-indicator" title="<?php _e( 'Click to toggle' ); ?>" aria-expanded="true"></div>
	</div>
	<div class="pinecast-feed-body">

		<div class="row">
			<div class="label"><?php
				_e( 'Podcast name', 'pinecast' );
				?><p class="description"><?php _e( 'The name of your podcast as it appears here, for your reference', 'pinecast' ); ?></p>
			</div>
			<div class="field">
				<input
					name="pinecast_feeds[<?php echo absint( $podcast->get_id() ); ?>][name]"
					type="text"
					value="<?php echo esc_attr( $podcast->get_name() ); ?>"
					class="feed-name otherwise-required"
					<?php if ($podcast->get_feed_url()) {echo 'required';} ?>
				>
			</div>
		</div>

		<div class="row">
			<div class="label"><?php _e( 'Feed URL', 'pinecast' ); ?></div>
			<div class="field">
				<input
					name="pinecast_feeds[<?php echo absint( $podcast->get_id() ); ?>][feed_url]"
					type="url"
					value="<?php echo esc_url( $podcast->get_feed_url() ); ?>"
					<?php if ($podcast->get_feed_url()) {echo 'readonly';} ?>
					pattern="https://.+"
					placeholder="https://pinecast.com/feed/…"
					class="otherwise-required"
					<?php if ($podcast->get_feed_url()) {echo 'required';} ?>
				>
			</div>
		</div>

		<div class="row">
			<div class="label"><?php
				_e( 'Category', 'pinecast' );
				?><p class="description"><?php _e( 'WordPress category assigned to posts created from this feed', 'pinecast' ); ?></p>
			</div>
			<div class="field"><?php
				$category_ids = $podcast->get_category_ids();
				wp_dropdown_categories( array(
					'show_option_none' => __( 'Do not assign a category', 'pinecast' ),
					'hide_empty'       => false,
					'selected'         => reset( $category_ids ), // Only one supported (for now)
					'name'             => 'pinecast_feeds[' . absint( $podcast->get_id() ) . '][categories][]',
				) );
			?></div>
		</div>

		<div class="row">
			<div class="label">
				<?php _e( 'Featured image', 'pinecast' ); ?>
				<p class="description"><?php _e( 'Copy unique episode artwork to WordPress', 'pinecast' ); ?></p>
			</div>
			<div class="field">
				<input name="pinecast_feeds[<?php echo absint( $podcast->get_id() ); ?>][featured_image]" type="checkbox" value="1" <?php checked( $podcast->use_featured_image() ); ?>>
				<label for="pinecast_feeds[<?php echo absint( $podcast->get_id() ); ?>][featured_image]">
					<?php _e( 'Use the episode artwork as featured image', 'pinecast' ); ?>
				</label>
				<br>
				<p class="description">
					<?php _e( 'Since artwork needs to be copied to your server, this option may increase sync times. For shows with many episodes and large artwork files, it may take multiple sync attempts to finish importing artwork.', 'pinecast' ); ?>
				</p>
			</div>
		</div>

		<?php if ($podcast->can_sync()) { ?>
			<div class="row actions">
				<div class="label"><?php _e( 'Actions', 'pinecast' ); ?></div>
				<div class="field">
					<a href="javascript:void(0);" <?php disabled( ! $podcast->can_sync() ) ?> class="pinecast-sync-now button button-secondary">
						<i class="dashicons dashicons-update"></i> <?php _e( 'Refresh feed', 'pinecast' ); ?>
					</a>
					<span class="spinner sync-spinner"></span>
					<br>
					<span class="description"><?php echo sprintf( __( 'Last updated: %s', 'pinecast' ), '<span class="last-updated">' . ($podcast->get_last_updated() ?? 'Never') ) . '</span>'; ?></span>
				</div>
			</div>
		<?php } ?>

		<?php do_action( 'pinecast/settings/feed/after' ); ?>
	</div>
</div>
