<?php
namespace Pinecast;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Manual podcast sync.
 *
 * Initiate a manual podcast sync.
 */
function ajax_sync_podcast() {
	if ( ! isset( $_POST['podcast'], $_POST['nonce'] ) ) {
		die(-1);
	}

	check_ajax_referer( 'pinecast-security', 'nonce' );

	if ( $podcast = get_podcast( wp_unslash($_POST['podcast']) ) ) {
		$podcast->sync_episodes();
		$podcast->sync_artwork();
		$podcast
			->set_last_updated()
			->update();
	} else {
		wp_send_json( array(
			'success' => false,
			'error' => 'podcast not found',
		) );
		return;
	}

	wp_send_json( array(
		'success' => true,
		'last_updated' => $podcast->get_last_updated(),
	) );
}
add_action( 'wp_ajax_pinecast_sync_podcast', 'Pinecast\ajax_sync_podcast' );


/**
 * Delete podcast.
 *
 * Delete a podcast.
 */
function ajax_delete_podcast() {
	if ( ! isset( $_POST['podcast'], $_POST['nonce'] ) ) {
		die(-1);
	}

	check_ajax_referer( 'pinecast-security', 'nonce' );

	$success = false;
	if ( $podcast = get_podcast( wp_unslash($_POST['podcast']) ) ) {
		$success = $podcast->delete();
	}

	wp_send_json( array(
		'success' => $success,
	) );
}
add_action( 'wp_ajax_pinecast_delete_podcast', 'Pinecast\ajax_delete_podcast' );
