<?php
namespace Pinecast;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Schedule events.
 *
 * Add events to the schedule related to feed sync.
 */
function schedule_events() {
	if ( ! wp_next_scheduled( 'pinecast/feed_sync' ) ) {
		wp_schedule_event( 1407110400, 'hourly', 'pinecast/feed_sync' ); // 1407110400 is 08 / 4 / 2014 @ 0:0:0 UTC
	}
}
add_action( 'init', '\Pinecast\schedule_events' );


/**
 * Check podcast feed.
 *
 * Check the podcast feeds to see if anything needs to be synced.
 */
function check_podcast_sync() {
	$start_time = time();

	$podcasts = get_podcasts();

	// Sort the podcast list by last updated (lexicographical sort == chronological sort) ascending.
	// We want to refresh the least-recently updated feed first.
	usort($podcasts, function ($a, $b) {
		return strcmp(strtolower($a->get_last_updated()), strtolower($b->get_last_updated()));
	});

	// First, sync episodes. This creates and updates posts with content and metadata.
	array_walk( $podcasts, function( $podcast ) {
		/** @var Podcast $podcast */
		$podcast->sync_episodes();

		$podcast->set_last_updated()
			->update();
	} );
	// After, we walk the podcasts again and sync artwork. This done separately, in case
	// artwork download causes timeouts.
	array_walk( $podcasts, function( $podcast ) use ($start_time) {
		/** @var Podcast $podcast */

		// If we're taking too long, abort artwork sync early.
		$now_time = time();
		if ($now_time - $start_time > 25) {
			return;
		}

		$podcast->sync_artwork();

		$podcast->set_last_updated()
			->update();

	} );
}
add_action( 'pinecast/feed_sync', '\Pinecast\check_podcast_sync' );
