'use strict';

(function($) {
  $(function() {
    $('.pinecast-feed').each(function() {
      $(this).pinecastFeed();
    });
  });

  $.fn.pinecastFeed = function() {
    new pinecastFeed(this);
    return this;
  };

  var methods = {
    init: function(options) {
      // Open/close
      this.find('.pinecast-feed-header').on('click', function(e) {
        $(this)
          .parents('.pinecast-feed')
          .pinecastFeed('toggle');
      });

      // Update name
      this.find('.feed-name').on('keyup', function(e) {
        $(this)
          .parents('.pinecast-feed')
          .pinecastFeed('updateName', e.target.value);
      });

      // Manual sync
      this.find('.pinecast-sync-now:not([disabled])').on('click', function(e) {
        e.preventDefault();
        $(this)
          .parents('.pinecast-feed')
          .pinecastFeed('sync');
      });
    },
    open: function() {
      this.addClass('open');
    },
    close: function() {
      this.removeClass('open');
    },
    toggle: function() {
      this.hasClass('open') ? this.pinecastFeed('close') : this.pinecastFeed('open');
    },
    updateName: function(value) {
      this.find('.pinecast-feed-header .title').html(value);
    },
    sync: function() {
      var $self = $(this);

      var button = $self.find('.pinecast-sync-now');
      if (button.hasClass('disabled')) {
        return;
      }
      button.addClass('disabled');

      var spinner = $self.find('.sync-spinner');
      spinner.addClass('is-active');

      var data = {
        action: 'pinecast_sync_podcast',
        podcast: $(this).attr('data-podcast-id'),
        nonce: pinecast.nonce,
      };
      $.post(ajaxurl, data, function(response) {
        spinner.removeClass('is-active');
        button.removeClass('disabled');

        if (response.last_updated) {
          $self.find('.last-updated').html(response.last_updated);
        }
      });
    },
    delete: function() {
      var data = {
        action: 'pinecast_delete_podcast',
        podcast: $(this).attr('data-podcast-id'),
        nonce: pinecast.nonce,
      };
      $.post(ajaxurl, data, function(response) {});
    },
  };

  $.fn.pinecastFeed = function(method) {
    if (methods[method]) {
      return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
    } else if (typeof method === 'object' || !method) {
      return methods.init.apply(this, arguments);
    } else {
      $.error('Method ' + method + ' does not exist on jQuery.pinecastFeed');
    }
  };

  /**************************************************************
   * Feed repeater setting
   *************************************************************/
  $('.pinecast-feeds-wrap').repeater({
    addTrigger: '#pinecast-add-podcast',
    removeTrigger: '.pinecast-feed .delete',
    template: '.pinecast-feed-template .pinecast-feed',
    elementWrap: '.pinecast-feed',
    elementsContainer: '.pinecast-feeds',
    removeElement: function(el) {
      el.remove();
      $(el).pinecastFeed('delete');
    },
    onAddElement: function(template, container, $self) {
      var new_id = Math.floor(Math.random() * 899999999 + 100000000); // Random number sequence of 9 length
      template.find('input[name], select[name]').attr('name', function(index, value) {
        return value.replace('9999', new_id) || value;
      });
      template.find('input[id], select[id]').attr('id', function(index, value) {
        return value.replace('9999', new_id) || value;
      });

      template.pinecastFeed();
      template.pinecastFeed('open');
    },
  });
})(jQuery);
