<?php
namespace Pinecast;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Get the podcast feeds.
 *
 * @return Podcast[] List of podcasts.
 */
function get_podcasts() {
	$podcast_feeds = get_option( 'pinecast_feeds', array() );

	$podcasts = array_map( function( $data, $id ) {
		return Podcast::create( $id, $data );
	}, $podcast_feeds, array_keys( $podcast_feeds ) );

    return $podcasts;
}


/**
 * Get a podcast.
 *
 * Get the podcast object based on the ID.
 *
 * @param int $id ID of the podcast.
 * @return Podcast|bool Podcast object when found, false otherwise.
 */
function get_podcast( $id ) {
    $podcast = array_reduce( get_podcasts(), function( $value, $podcast ) use ( $id ) {
		return $podcast->get_id() == $id ? $podcast : $value;
	}, false );

    return $podcast;
}
