<?php
namespace Pinecast {

	/**
	 * Class Pinecast
	 */
	class Pinecast {

		/** @var string Plugin version */
		public $version = '1.0.0';

		/** @var string Main plugin file */
		public $file = PINECAST_FILE;

		/** @var Pinecast Main plugin instance */
		private static $instance;


		/**
		 * Constructor.
		 *
		 * @since 1.0.0
		 */
		public function __construct() {

		}


		/**
		 * Instance.
		 *
		 * An global instance of the class. Used to retrieve the instance
		 * to use on other files/plugins/themes.
		 *
		 * @since 1.0.0
		 * @return  object Instance of the class.
		 */
		public static  function instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}


		/**
		 * Initialize plugin parts.
		 *
		 * @since 1.0.0
		 */
		public function init() {
			// Load textdomain
			$this->load_textdomain();

			// Admin
			if ( is_admin() ) {
				$this->admin = new \Pinecast\Admin\Admin();
				$this->admin->init();
			}
		}


		/**
		 * Textdomain.
		 *
		 * Load the textdomain based on WP language.
		 *
		 * @since 1.0.0
		 */
		public function load_textdomain() {
			load_plugin_textdomain( 'pinecast', false, basename( dirname( __FILE__ ) ) . '/languages' );
		}
	}

}

namespace {

	/**
	 * The main function responsible for returning the Pinecast object.
	 *
	 * Use this function like you would a global variable, except without needing to declare the global.
	 *
	 * Example: <?php Pinecast()->method_name(); ?>
	 *
	 * @since 1.0.0
	 *
	 * @return \Pinecast\Pinecast Return the singleton Pinecast object.
	 */
	function Pinecast() {
		return \Pinecast\Pinecast::instance();
	}
	Pinecast()->init();
}
